Index: webrtc/modules/utility/include/jvm_android.h |
diff --git a/webrtc/modules/utility/include/jvm_android.h b/webrtc/modules/utility/include/jvm_android.h |
index 574c977cd0498f48f05334e5132bb6afddaa288a..f527dff6322cc6ae19a7d18f8ffe14d8901916bd 100644 |
--- a/webrtc/modules/utility/include/jvm_android.h |
+++ b/webrtc/modules/utility/include/jvm_android.h |
@@ -12,10 +12,9 @@ |
#define WEBRTC_MODULES_UTILITY_INCLUDE_JVM_ANDROID_H_ |
#include <jni.h> |
- |
-#include <memory> |
#include <string> |
+#include "webrtc/base/scoped_ptr.h" |
#include "webrtc/base/thread_checker.h" |
#include "webrtc/modules/utility/include/helpers_android.h" |
@@ -77,7 +76,7 @@ |
NativeRegistration(JNIEnv* jni, jclass clazz); |
~NativeRegistration(); |
- std::unique_ptr<GlobalRef> NewObject( |
+ rtc::scoped_ptr<GlobalRef> NewObject( |
const char* name, const char* signature, ...); |
private: |
@@ -97,7 +96,7 @@ |
// Note that the class name must be one of the names in the static |
// |loaded_classes| array defined in jvm_android.cc. |
// This method must be called on the construction thread. |
- std::unique_ptr<NativeRegistration> RegisterNatives( |
+ rtc::scoped_ptr<NativeRegistration> RegisterNatives( |
const char* name, const JNINativeMethod *methods, int num_methods); |
// Converts from Java string to std::string. |
@@ -121,9 +120,9 @@ |
// webrtc::JVM::Initialize(jvm, context); |
// |
// // Header (.h) file of example class called User. |
// std::unique_ptr<JNIEnvironment> env; |
// std::unique_ptr<NativeRegistration> reg; |
// std::unique_ptr<GlobalRef> obj; |
// |
// // Construction (in .cc file) of User class. |
// User::User() { |
@@ -157,7 +156,7 @@ |
// Creates a JNIEnvironment object. |
// This method returns a NULL pointer if AttachCurrentThread() has not been |
// called successfully. Use the AttachCurrentThreadIfNeeded class if needed. |
- std::unique_ptr<JNIEnvironment> environment(); |
+ rtc::scoped_ptr<JNIEnvironment> environment(); |
// Returns a JavaClass object given class |name|. |
// Note that the class name must be one of the names in the static |
@@ -121,9 +120,9 @@ |
// |
// // Header (.h) file of example class called User. |
-// std::unique_ptr<JNIEnvironment> env; |
-// std::unique_ptr<NativeRegistration> reg; |
-// std::unique_ptr<GlobalRef> obj; |
+// rtc::scoped_ptr<JNIEnvironment> env; |
+// rtc::scoped_ptr<NativeRegistration> reg; |
+// rtc::scoped_ptr<GlobalRef> obj; |
// |
// // Construction (in .cc file) of User class. |